You are viewing a plain text version of this content. The canonical link for it is here.
Posted to cvs@cocoon.apache.org by mi...@apache.org on 2006/07/22 11:53:02 UTC

svn commit: r424541 - /cocoon/trunk/core/cocoon-core/src/main/java/org/apache/cocoon/generation/StreamGenerator.java

Author: michi
Date: Sat Jul 22 02:53:00 2006
New Revision: 424541

URL: http://svn.apache.org/viewvc?rev=424541&view=rev
Log:
missing xhtml mime-type added

Modified:
    cocoon/trunk/core/cocoon-core/src/main/java/org/apache/cocoon/generation/StreamGenerator.java

Modified: cocoon/trunk/core/cocoon-core/src/main/java/org/apache/cocoon/generation/StreamGenerator.java
URL: http://svn.apache.org/viewvc/cocoon/trunk/core/cocoon-core/src/main/java/org/apache/cocoon/generation/StreamGenerator.java?rev=424541&r1=424540&r2=424541&view=diff
==============================================================================
--- cocoon/trunk/core/cocoon-core/src/main/java/org/apache/cocoon/generation/StreamGenerator.java (original)
+++ cocoon/trunk/core/cocoon-core/src/main/java/org/apache/cocoon/generation/StreamGenerator.java Sat Jul 22 02:53:00 2006
@@ -49,7 +49,7 @@
  * sitemap parameter 'form-name'.
  *
  * For the POST requests with mimetypes: text/plain, text/xml,
  * application/xml the xml data is in the body of the POST request and
  * its length is specified by the value returned by getContentLength()
  * method.  The StreamGenerator uses helper
  * org.apache.cocoon.util.PostInputStream class for InputStream
@@ -123,6 +123,7 @@
                 inputSource = new InputSource(xmlReader);
             } else if (contentType.startsWith("text/plain") ||
                     contentType.startsWith("text/xml") ||
+                    contentType.startsWith("application/xhtml+xml") ||
                     contentType.startsWith("application/xml")) {
 
                 HttpServletRequest httpRequest = (HttpServletRequest) objectModel.get(HttpEnvironment.HTTP_REQUEST_OBJECT);
@@ -49,7 +49,7 @@
  *
  * For the POST requests with mimetypes: text/plain, text/xml,
- * application/xml the xml data is in the body of the POST request and
+ * application/xhtml+xml, application/xml the xml data is in the body of the POST request and
  * its length is specified by the value returned by getContentLength()
  * method.  The StreamGenerator uses helper